@@ -1,10 +1,9 @@
 package File::NCopy;
-require 5.004; # just because I think you should upgrade :)
+use 5.004; # just because I think you should upgrade :)
 
 =head1 NAME
 
-B<File::NCopy> - Copy file, file
-              Copy file[s] | dir[s], dir
+File::NCopy - Deprecated module. Use File::Copy::Recursive instead. Copy file, file. Copy file[s] | dir[s], dir
 
 =head1 SYNOPSIS
 
@@ -165,7 +164,7 @@ On Win32, The use of backslash for paths is required.
 
 =head1 AUTHOR
 
-Gabor Egressy B<gabor@vmunix.com>
+Gabor Egressy B<gabor AT vmunix.com>
 
 Copyright (c) 1998 Gabor Egressy.  All rights reserved.  All wrongs
 reversed.  This program is free software; you can redistribute and/or
@@ -176,6 +175,8 @@ but the code was written from scratch.
 
 Patch at versions 0.33, and 0.34 added by MZSANFORD.
 
+0.35, 0.36 - Alexandr Ciornii (alexchorny AT gmail.com)
+
 =cut
 
 use Cwd ();
@@ -186,7 +187,7 @@ use vars qw(@EXPORT_OK @ISA $VERSION);
 # we export nothing by default :)
 @EXPORT_OK = qw(copy cp);
 
-$VERSION = '0.34';
+$VERSION = '0.36';
 
 # this works on Unix
 sub u_chmod($$)
@@ -354,7 +355,7 @@ sub get_path($)
     $dir = Cwd::cwd;
     chdir $save_dir;
 
-    $dir;
+    return $dir;
 }
 
 sub _recurse_from_dir($$$);
@@ -440,7 +441,7 @@ sub _recurse_from_dir($$$)
         delete $this->{'_links'}->{$save_link};
     }
 
-    $retval;
+    return $retval;
 }
 
 sub _docopy_dir_dir($$$)
@@ -538,7 +539,7 @@ sub expand(@)
     @args;
 }
 
-sub new(@);
+sub new(@); #prototype
 
 # this just redirects calls
 sub copy(@)
@@ -561,7 +562,7 @@ sub copy(@)
     my @copies;
     my @args = expand @_;
 
-    print "passed args ==> @args\n"
+    print "passed args ==> ".join(',',map {"'$_'"} @args)."\n"
         if $this->{'_debug'};
 
     # one or more files/directories to a directory
